==> fltk-docs-1.3.11-1-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/search/functions_16.js <==
var searchData=
[
  ['x_0',['x',['../group__fl__screen.html#ga129f4b9d14ad1d720d60b7881693d6ec',1,'Fl::x()'],['../classFl__Help__Dialog.html#a717450488feb6c62ae1c0a5b0504816c',1,'Fl_Help_Dialog::x()'],['../classFl__Tree__Item.html#af3879c09adc276634eb0ac3262a2dcbe',1,'Fl_Tree_Item::x()'],['../classFl__Widget.html#abea0b9ad493d58bf7fda8d3c81d477b7',1,'Fl_Widget::x(int v)'],['../classFl__Widget.html#aeed320ce65d02a7f0fcab1363f0136b0',1,'Fl_Widget::x() const']]],
  ['x_5froot_1',['x_root',['../classFl__Window.html#a26be3fa772a044d4c922b261b1df60bd',1,'Fl_Window']]],
  ['x_5fto_5fcol_2',['x_to_col',['../classFl__Text__Display.html#a69139918fadc2ea30d5c16583fc8d0c8',1,'Fl_Text_Display']]],
  ['xbounds_3',['xbounds',['../classFl__Positioner.html#abe43df59869974dc501f1d9b29b931b4',1,'Fl_Positioner']]],
  ['xclass_4',['xclass',['../classFl__Window.html#a5f4838ae3f1100495d1f4eeca6c33397',1,'Fl_Window::xclass() const'],['../classFl__Window.html#a913bb4f81e4627e5b4a860ef78bca1ff',1,'Fl_Window::xclass(const char *c)']]],
  ['xmaximum_5',['xmaximum',['../classFl__Positioner.html#af570d7f8643a723c57ad6a5f5f34b854',1,'Fl_Positioner::xmaximum() const'],['../classFl__Positioner.html#a1266ba5b972684673eb2274ec5371226',1,'Fl_Positioner::xmaximum(double a)']]],
  ['xminimum_6',['xminimum',['../classFl__Positioner.html#a39b666f14b3c97a4e9e3dec680a0e932',1,'Fl_Positioner::xminimum() const'],['../classFl__Positioner.html#a12c59eca4d22ac86e77515c925192bc9',1,'Fl_Positioner::xminimum(double a)']]],
  ['xposition_7',['xposition',['../classFl__Scroll.html#a83b1ac53e5d35d83b9b804e03891363a',1,'Fl_Scroll']]],
  ['xstep_8',['xstep',['../classFl__Positioner.html#a8c73c15b3152110c95c3c10ed32bcbbe',1,'Fl_Positioner']]],
  ['xvalue_9',['xvalue',['../classFl__Positioner.html#a7c494d5e947ef4edaf5268a9216b9e27',1,'Fl_Positioner::xvalue() const'],['../classFl__Positioner.html#a5c3090ebf46d34525eadd24fd54ec5d5',1,'Fl_Positioner::xvalue(double)']]],
  ['xy_5fto_5fposition_10',['xy_to_position',['../classFl__Text__Display.html#a3048c33ca31c4ccb39ca6dff352aa47b',1,'Fl_Text_Display']]],
  ['xy_5fto_5frowcol_11',['xy_to_rowcol',['../classFl__Text__Display.html#ac2fd9e9ef877f35a20136b9a2be54553',1,'Fl_Text_Display']]],
  ['xyline_12',['xyline',['../classFl__Graphics__Driver.html#a6c32e74f0acf34752916022eeadd5aec',1,'Fl_Graphics_Driver::xyline(int x, int y, int x1)'],['../classFl__Graphics__Driver.html#a812989f1771890012bae336cf217332d',1,'Fl_Graphics_Driver::xyline(int x, int y, int x1, int y2)'],['../classFl__Graphics__Driver.html#af3db15156cde85529370b6c8bef88632',1,'Fl_Graphics_Driver::xyline(int x, int y, int x1, int y2, int x3)'],['../classFl__PostScript__Graphics__Driver.html#a6d7660c3c0356023663524533e1bbea2',1,'Fl_PostScript_Graphics_Driver::xyline(int x, int y, int x1)'],['../classFl__PostScript__Graphics__Driver.html#a67949ccc791aa8b9cac4301d7839d2fc',1,'Fl_PostScript_Graphics_Driver::xyline(int x, int y, int x1, int y2)'],['../classFl__PostScript__Graphics__Driver.html#a45bc3145d11c0b4f9bee548affd4e811',1,'Fl_PostScript_Graphics_Driver::xyline(int x, int y, int x1, int y2, int x3)']]]
];

==> fltk-docs-1.4.4-3-x86_64.pkg.tar.zst: usr/share/doc/fltk/html/search/functions_16.js <==
var searchData=
[
  ['x_0',['x',['../group__fl__screen.html#gaed836eacded3467aa838d02a1c55e3ab',1,'Fl::x()'],['../classFl__Help__Dialog.html#a717450488feb6c62ae1c0a5b0504816c',1,'Fl_Help_Dialog::x()'],['../classFl__Rect.html#adc9398d9fc8d183e27d1157fcbfa3b3a',1,'Fl_Rect::x() const'],['../classFl__Rect.html#a8cb963d17d68c23b8f096fa3dd728a10',1,'Fl_Rect::x(int X)'],['../classFl__Tree__Item.html#af3879c09adc276634eb0ac3262a2dcbe',1,'Fl_Tree_Item::x()'],['../classFl__Widget.html#abea0b9ad493d58bf7fda8d3c81d477b7',1,'Fl_Widget::x(int v)'],['../classFl__Widget.html#aeed320ce65d02a7f0fcab1363f0136b0',1,'Fl_Widget::x() const']]],
  ['x_5froot_1',['x_root',['../classFl__Window.html#a26be3fa772a044d4c922b261b1df60bd',1,'Fl_Window']]],
  ['x_5fto_5fcol_2',['x_to_col',['../classFl__Text__Display.html#a69139918fadc2ea30d5c16583fc8d0c8',1,'Fl_Text_Display']]],
  ['xbounds_3',['xbounds',['../classFl__Positioner.html#abe43df59869974dc501f1d9b29b931b4',1,'Fl_Positioner']]],
  ['xclass_4',['xclass',['../classFl__Window.html#a5f4838ae3f1100495d1f4eeca6c33397',1,'Fl_Window::xclass() const'],['../classFl__Window.html#a913bb4f81e4627e5b4a860ef78bca1ff',1,'Fl_Window::xclass(const char *c)']]],
  ['xmaximum_5',['xmaximum',['../classFl__Positioner.html#af570d7f8643a723c57ad6a5f5f34b854',1,'Fl_Positioner::xmaximum() const'],['../classFl__Positioner.html#a1266ba5b972684673eb2274ec5371226',1,'Fl_Positioner::xmaximum(double a)']]],
  ['xminimum_6',['xminimum',['../classFl__Positioner.html#a39b666f14b3c97a4e9e3dec680a0e932',1,'Fl_Positioner::xminimum() const'],['../classFl__Positioner.html#a12c59eca4d22ac86e77515c925192bc9',1,'Fl_Positioner::xminimum(double a)']]],
  ['xposition_7',['xposition',['../classFl__Scroll.html#a83b1ac53e5d35d83b9b804e03891363a',1,'Fl_Scroll']]],
  ['xstep_8',['xstep',['../classFl__Positioner.html#a8c73c15b3152110c95c3c10ed32bcbbe',1,'Fl_Positioner']]],
  ['xvalue_9',['xvalue',['../classFl__Positioner.html#a7c494d5e947ef4edaf5268a9216b9e27',1,'Fl_Positioner::xvalue() const'],['../classFl__Positioner.html#a5c3090ebf46d34525eadd24fd54ec5d5',1,'Fl_Positioner::xvalue(double)']]],
  ['xy_5fto_5fposition_10',['xy_to_position',['../classFl__Text__Display.html#a3048c33ca31c4ccb39ca6dff352aa47b',1,'Fl_Text_Display']]],
  ['xy_5fto_5frowcol_11',['xy_to_rowcol',['../classFl__Text__Display.html#ac2fd9e9ef877f35a20136b9a2be54553',1,'Fl_Text_Display']]]
];
